<?php

/**
 * ====================================================
 * Process/Get repositioned table header
 * ====================================================
 */

if( !function_exists( 'pvtfw_process_table_header' ) ){

    function pvtfw_process_table_header(){

        $default_columns = PVTFW_COMMON::get_default_columns();
        $columns_labels = PVTFW_COMMON::get_columns_labels();
        $columns = (array) get_option('pvtfw_variant_table_columns', $default_columns);


        // Removing off values from with column

        foreach($columns as $key=>$value)
        {
            if(is_null($value) || $value == 'off')
            unset($columns[$key]);
        }

        // New array initialization depending on column repositioning
        $latest = array();

        // Depending on column repositioning making output array
        foreach ($columns as $key => $value){
            if(!is_null($value) || $value != 'off'){
                $latest[$key] = $columns_labels[$key];
            }
        }

        return $latest;
    }

}

/**
 * ====================================================
 * Getting Product Attribute Labels
 * ====================================================
 */
if( !function_exists( 'get_attr_label' ) ){

    function get_attr_label(){

        global $product;

        // Array to retrun label
        $attr_lbl = [];

        // Get the attribute label
        foreach ($product->get_variation_attributes() as $taxonomy => $term_names ) {
            $attr_lbl[] = wc_attribute_label($taxonomy);
        }
        return $attr_lbl;
    }

}

/**
 * ====================================================
 * Print table data for table head
 * ====================================================
 */

if( !function_exists( 'pvtfw_print_table_header' ) ){

    function pvtfw_print_table_header(){

        $latest = pvtfw_process_table_header();
        $attr_lbl = get_attr_label();

        /**
         * Hook: pvtfw_pro_thead_th.
         *
         * @hooked 
         */
        do_action('pvtfw_pro_thead_th');

        foreach ($latest as $key => $label) {
            if($label == __("Action", "product-variant-table-for-woocommerce")){
                echo "<th class='{$key}'>&nbsp;</th>";
            }
            elseif($label == __("Attributes", "product-variant-table-for-woocommerce")){
                foreach($attr_lbl as $key => $lbl){
                    echo "<th class='{$lbl} sortable asc'>{$lbl}<span class='arrow'></span></th>";
                }
            }
            else{
                echo "<th class='{$key} sortable asc'>{$label}<span class='arrow'></span></th>";
            }
        }

        /**
         * ================================
         * Subtotal code here
         * ================================
         */
        $showSubTotal = PVTFW_COMMON::pvtfw_get_options()->showSubTotal;
        if($showSubTotal != ''):
            echo apply_filters('pvtfw_subtotal_title', "<th>".__("SubTotal", "product-variant-table-for-woocommerce")."</th>");
        endif;
    }

    add_action('pvtfw_table_header', 'pvtfw_print_table_header', 99);

}